@@ -3,6 +3,7 @@ import os, struct
 verbose = True
 verbose = False
 
+afs_home = os.path.join('afs', 'ipp-garching.mpg.de/home')
 
 def sf_path(nshot, diag, exp='AUGD', ed=0):
 
@@ -17,7 +18,7 @@ def sf_path(nshot, diag, exp='AUGD', ed=0):
         return None, None
 
     if exp == 'augd':
-        sf_dir = '/afs/ipp-garching.mpg.de/home/a/augd/shots/%s' %(sshot[:4])
+        sf_dir = '%s/a/augd/shots/%s' %(afs_home, sshot[:4])
         a = os.listdir(sf_dir)
         path_out = None
         for subdir in a:
@@ -29,7 +30,7 @@ def sf_path(nshot, diag, exp='AUGD', ed=0):
                     path_out = '%s/%d.%d' %(path1, nshot, ed)
                 break
     else:
-        path1 = '/afs/ipp-garching.mpg.de/home/%s/%s/shotfiles/%s/%s' %(exp[0], exp, diag, sshot[:2])
+        path1 = '%s/%s/%s/shotfiles/%s/%s' %(afs_home, exp[0], exp, diag, sshot[:2])
         if os.path.isdir(path1):
             if not os.path.isfile('%s/ed_cntl' %path1):
                 path_out = '%s/%s' %(path1, sshot[2:])
@@ -46,7 +47,7 @@ def ed_zero(diag, nshot, exp='augd'):
     diag = diag.upper()
 
     if exp == 'augd':
-        sf_dir = '/afs/ipp-garching.mpg.de/home/a/augd/shots/%s' %(sshot[:4])
+        sf_dir = '%s/a/augd/shots/%s' %(afs_home, sshot[:4])
         if not os.path.isdir(sf_dir):
             return None
         a = os.listdir(sf_dir)
@@ -58,7 +59,7 @@ def ed_zero(diag, nshot, exp='augd'):
                     return 1
                 break
     else:
-        fed_dir = '/afs/ipp-garching.mpg.de/home/%s/%s/shotfiles/%s/%s' %(exp[0], exp, diag, sshot[:2])
+        fed_dir = '%s/%s/%s/shotfiles/%s/%s' %(afs_home, exp[0], exp, diag, sshot[:2])
         nshot = nshot % 1000
         if not os.path.isdir(fed_dir):
             return None
@@ -113,12 +114,12 @@ def read_ed_cntl(fed_dir, exp='augd'):
 
 if __name__ == '__main__':
 
-    fed_in = '/afs/ipp-garching.mpg.de/home/g/git/shotfiles/TRA/35'
+    fed_in = '%s/g/git/shotfiles/TRA/35' %afs_home
     ed = read_ed_cntl(fed_in, exp='git')
     print(fed_in)
     print(ed)
-    fed_in = '/afs/ipp-garching.mpg.de/home/a/augd/shots/3956/L1/NSP'
-    fed_in = '/afs/ipp-garching.mpg.de/home/a/augd/shots/3956/L1/TOT'
+    fed_in = '%s/a/augd/shots/3956/L1/NSP' %afs_home
+    fed_in = '%s/a/augd/shots/3956/L1/TOT' %afs_home
     ed = read_ed_cntl(fed_in)
     print(fed_in)
     print(ed)
