@@ -161,6 +161,9 @@ class SFREAD:
 
         if 'sfh' in kwargs.keys():
             self.sfile = kwargs['sfh']
+        if 'sf' in kwargs.keys():
+            self.sfile = kwargs['sf']
+        if hasattr(self, 'sfile'):
             self.shot = 0
             self.ed = 0
             self.diag = os.path.basename(self.sfile)[:3]
